

# Handlers
ON_SAVE_SESSION = 'on_save_session'
ON_FIND_SESSION = 'on_find_session'
ON_DEL_SESSION = 'on_del_session'
ON_BROKER_POST_SHUTDOWN = 'on_broker_post_shutdown'
ON_MQTT_PACKET_RECEIVED = 'on_mqtt_packet_received'

# YAML
BASE_CONFIG_PATH = 'plugins'
PAYLOAD_CONFIG = 'payload'

AMQTT_PLUGIN_NAME = 'amqtt_db'

TOPIC_ENGINE = 'topic_engine'
DB_CONNECT_STRING = 'db_connection'

DB_STRUCTURE = 'db_structure'
